@@ -1,7 +1,5 @@
 package LWP::Simple;
 
-# $Id: Simple.pm,v 1.39 2004/04/06 11:46:44 gisle Exp $
-
 use strict;
 use vars qw($ua %loop_check $FULL_LWP @EXPORT @EXPORT_OK $VERSION);
 
@@ -16,51 +14,27 @@ require Exporter;
 use HTTP::Status;
 push(@EXPORT, @HTTP::Status::EXPORT);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.39 $ =~ /(\d+)\.(\d+)/);
-$FULL_LWP++ if grep {lc($_) eq "http_proxy"} keys %ENV;
-
+$VERSION = "5.827";
 
 sub import
 {
     my $pkg = shift;
     my $callpkg = caller;
-    if (grep $_ eq '$ua', @_) {
-	$FULL_LWP++;
-	_init_ua();
-    }
     Exporter::export($pkg, $callpkg, @_);
 }
 
-
-sub _init_ua
-{
-    require LWP;
-    require LWP::UserAgent;
-    require HTTP::Status;
-    require HTTP::Date;
-    $ua = new LWP::UserAgent;  # we create a global UserAgent object
-    my $ver = $LWP::VERSION = $LWP::VERSION;  # avoid warning
-    $ua->agent("LWP::Simple/$LWP::VERSION");
-    $ua->env_proxy;
-}
+use LWP::UserAgent ();
+use HTTP::Status ();
+use HTTP::Date ();
+$ua = new LWP::UserAgent;  # we create a global UserAgent object
+$ua->agent("LWP::Simple/$VERSION ");
+$ua->env_proxy;
 
 
 sub get ($)
 {
-    %loop_check = ();
-    goto \&_get;
-}
-
-
-sub get_old ($)
-{
-    my($url) = @_;
-    _init_ua() unless $ua;
-
-    my $request = HTTP::Request->new(GET => $url);
-    my $response = $ua->request($request);
-
-    return $response->content if $response->is_success;
+    my $response = $ua->get(shift);
+    return $response->decoded_content if $response->is_success;
     return undef;
 }
 
@@ -68,8 +42,6 @@ sub get_old ($)
 sub head ($)
 {
     my($url) = @_;
-    _init_ua() unless $ua;
-
     my $request = HTTP::Request->new(HEAD => $url);
     my $response = $ua->request($request);
 
@@ -89,8 +61,6 @@ sub head ($)
 sub getprint ($)
 {
     my($url) = @_;
-    _init_ua() unless $ua;
-
     my $request = HTTP::Request->new(GET => $url);
     local($\) = ""; # ensure standard $OUTPUT_RECORD_SEPARATOR
     my $callback = sub { print $_[0] };
@@ -108,8 +78,6 @@ sub getprint ($)
 sub getstore ($$)
 {
     my($url, $file) = @_;
-    _init_ua() unless $ua;
-
     my $request = HTTP::Request->new(GET => $url);
     my $response = $ua->request($request, $file);
 
@@ -120,80 +88,11 @@ sub getstore ($$)
 sub mirror ($$)
 {
     my($url, $file) = @_;
-    _init_ua() unless $ua;
     my $response = $ua->mirror($url, $file);
     $response->code;
 }
 
 
-sub _get
-{
-    my $url = shift;
-    my $ret;
-    if (!$FULL_LWP && $url =~ m,^http://([^/:\@]+)(?::(\d+))?(/\S*)?$,) {
-	my $host = $1;
-	my $port = $2 || 80;
-	my $path = $3;
-	$path = "/" unless defined($path);
-	return _trivial_http_get($host, $port, $path);
-    }
-    else {
-        _init_ua() unless $ua;
-	if (@_ && $url !~ /^\w+:/) {
-	    # non-absolute redirect from &_trivial_http_get
-	    my($host, $port, $path) = @_;
-	    require URI;
-	    $url = URI->new_abs($url, "http://$host:$port$path");
-	}
-	my $request = HTTP::Request->new(GET => $url);
-	my $response = $ua->request($request);
-	return $response->is_success ? $response->content : undef;
-    }
-}
-
-
-sub _trivial_http_get
-{
-   my($host, $port, $path) = @_;
-   #print "HOST=$host, PORT=$port, PATH=$path\n";
-
-   require IO::Socket;
-   local($^W) = 0;
-   my $sock = IO::Socket::INET->new(PeerAddr => $host,
-                                    PeerPort => $port,
-                                    Proto    => 'tcp',
-                                    Timeout  => 60) || return undef;
-   $sock->autoflush;
-   my $netloc = $host;
-   $netloc .= ":$port" if $port != 80;
-   print $sock join("\015\012" =>
-                    "GET $path HTTP/1.0",
-                    "Host: $netloc",
-                    "User-Agent: lwp-trivial/$VERSION",
-                    "", "");
-
-   my $buf = "";
-   my $n;
-   1 while $n = sysread($sock, $buf, 8*1024, length($buf));
-   return undef unless defined($n);
-
-   if ($buf =~ m,^HTTP/\d+\.\d+\s+(\d+)[^\012]*\012,) {
-       my $code = $1;
-       #print "CODE=$code\n$buf\n";
-       if ($code =~ /^30[1237]/ && $buf =~ /\012Location:\s*(\S+)/i) {
-           # redirect
-           my $url = $1;
-           return undef if $loop_check{$url}++;
-           return _get($url, $host, $port, $path);
-       }
-       return undef unless $code =~ /^2/;
-       $buf =~ s/.+?\015?\012\015?\012//s;  # zap header
-   }
-
-   return $buf;
-}
-
-
 1;
 
 __END__
@@ -252,9 +151,10 @@ successful.
 =item getprint($url)
 
 Get and print a document identified by a URL. The document is printed
-to STDOUT as data is received from the network.  If the request fails,
-then the status code and message are printed on STDERR.  The return
-value is the HTTP response code.
+to the selected default filehandle for output (normally STDOUT) as
+data is received from the network.  If the request fails, then the
+status code and message are printed on STDERR.  The return value is
+the HTTP response code.
 
 =item getstore($url, $file)
 
@@ -321,7 +221,7 @@ True if response code indicated a successful request.
 
 =item is_error($rc)
 
-True if response code indicated that an error occured.
+True if response code indicated that an error occurred.
 
 =back
 
@@ -329,7 +229,7 @@ The module will also export the LWP::UserAgent object as C<$ua> if you
 ask for it explicitly.
 
 The user agent created by this module will identify itself as
-"LWP::Simple/#.##" (where "#.##" is the libwww-perl version number)
+"LWP::Simple/#.##"
 and will initialize its proxy defaults from the environment (by
 calling $ua->env_proxy).
 
