@@ -5,7 +5,7 @@ use vars qw(@ISA $VERSION);
 
 require LWP::MemberMixin;
 @ISA = qw(LWP::MemberMixin);
-$VERSION = "5.827";
+$VERSION = "5.829";
 
 use HTTP::Request ();
 use HTTP::Response ();
@@ -595,8 +595,9 @@ sub parse_head {
 		       return unless $parser;
 		       unless ($parser->parse($_[3])) {
 			   my $h = $parser->header;
+			   my $r = $_[0];
 			   for my $f ($h->header_field_names) {
-			       $response->init_header($f, [$h->header($f)]);
+			       $r->init_header($f, [$h->header($f)]);
 			   }
 			   undef($parser);
 		       }
@@ -823,47 +824,50 @@ sub mirror
 
     my $request = HTTP::Request->new('GET', $url);
 
-    if (-e $file) {
-	my($mtime) = (stat($file))[9];
-	if($mtime) {
-	    $request->header('If-Modified-Since' =>
-			     HTTP::Date::time2str($mtime));
-	}
+    # If the file exists, add a cache-related header
+    if ( -e $file ) {
+        my ($mtime) = ( stat($file) )[9];
+        if ($mtime) {
+            $request->header( 'If-Modified-Since' => HTTP::Date::time2str($mtime) );
+        }
     }
     my $tmpfile = "$file-$$";
 
     my $response = $self->request($request, $tmpfile);
-    if ($response->is_success) {
 
-	my $file_length = (stat($tmpfile))[7];
-	my($content_length) = $response->header('Content-length');
+    # Only fetching a fresh copy of the would be considered success.
+    # If the file was not modified, "304" would returned, which 
+    # is considered by HTTP::Status to be a "redirect", /not/ "success"
+    if ( $response->is_success ) {
+        my $file_length = ( stat($tmpfile) )[7];
+        my ($content_length) = $response->header('Content-length');
 
-	if (defined $content_length and $file_length < $content_length) {
-	    unlink($tmpfile);
-	    die "Transfer truncated: " .
-		"only $file_length out of $content_length bytes received\n";
-	}
-	elsif (defined $content_length and $file_length > $content_length) {
-	    unlink($tmpfile);
-	    die "Content-length mismatch: " .
-		"expected $content_length bytes, got $file_length\n";
-	}
-	else {
-	    # OK
-	    if (-e $file) {
-		# Some dosish systems fail to rename if the target exists
-		chmod 0777, $file;
-		unlink $file;
-	    }
-	    rename($tmpfile, $file) or
-		die "Cannot rename '$tmpfile' to '$file': $!\n";
+        if ( defined $content_length and $file_length < $content_length ) {
+            unlink($tmpfile);
+            die "Transfer truncated: " . "only $file_length out of $content_length bytes received\n";
+        }
+        elsif ( defined $content_length and $file_length > $content_length ) {
+            unlink($tmpfile);
+            die "Content-length mismatch: " . "expected $content_length bytes, got $file_length\n";
+        }
+        # The file was the expected length. 
+        else {
+            # Replace the stale file with a fresh copy
+            if ( -e $file ) {
+                # Some dosish systems fail to rename if the target exists
+                chmod 0777, $file;
+                unlink $file;
+            }
+            rename( $tmpfile, $file )
+                or die "Cannot rename '$tmpfile' to '$file': $!\n";
 
-	    if (my $lm = $response->last_modified) {
-		# make sure the file has the same last modification time
-		utime $lm, $lm, $file;
-	    }
-	}
+            # make sure the file has the same last modification time
+            if ( my $lm = $response->last_modified ) {
+                utime $lm, $lm, $file;
+            }
+        }
     }
+    # The local copy is fresh enough, so just delete the temp file  
     else {
 	unlink($tmpfile);
     }
